@@ -47,6 +47,14 @@ class JobEnvironment:
             n = n[: -len("JobEnvironment")]
         return n.lower()
 
+    @property
+    def paths(self) -> JobPaths:
+        """Provides the paths used by submitit, including
+        stdout, stderr, submitted_pickle and folder.
+        """
+        folder = os.environ["SUBMITIT_FOLDER"]
+        return JobPaths(folder, job_id=self.job_id, task_id=self.global_rank)
+
     def activated(self) -> bool:
         """Tests if we are running inside this environment.
 
@@ -116,7 +124,8 @@ class JobEnvironment:
         names = ("local_rank", "node", "global_rank")
         totals = [self.num_tasks // self.num_nodes, self.num_nodes, self.num_tasks]
         info += [f"{n}={getattr(self, n)}({t})" for n, t in zip(names, totals)]
-        return "JobEnvironment({})".format(", ".join(info))
+        info_str = ", ".join(info)
+        return f"JobEnvironment({info_str})"
 
     def _handle_signals(self, paths: JobPaths, submission: DelayedSubmission) -> None:
         """Set up signals handler for the current executable.
