@@ -4,6 +4,7 @@
 # LICENSE file in the root directory of this source tree.
 #
 
+import functools
 import os
 import re
 import signal
@@ -50,7 +51,7 @@ def test_local_job(tmp_path: Path) -> None:
     assert job2.done()
 
 
-def test_local_job_array(tmp_path: Path) -> None:
+def test_local_map_array(tmp_path: Path) -> None:
     n = 5
     data1, data2 = range(n), range(10, 10 + n)
 
@@ -65,6 +66,22 @@ def test_local_job_array(tmp_path: Path) -> None:
     assert list(map(f, data1, data2)) == [j.result() for j in jobs]
 
 
+def test_local_submit_array(tmp_path: Path) -> None:
+    n = 5
+    data1, data2 = range(n), range(10, 10 + n)
+
+    def f(x: int, y: int) -> int:
+        assert x in data1
+        assert y in data2
+        return x + y
+
+    executor = local.LocalExecutor(tmp_path)
+    fns = [functools.partial(f, x, y) for x, y in zip(data1, data2)]
+    jobs = executor.submit_array(fns)
+
+    assert list(map(f, data1, data2)) == [j.result() for j in jobs]
+
+
 def test_local_error(tmp_path: Path) -> None:
     def failing_job() -> None:
         raise Exception("Failed on purpose")
@@ -237,3 +254,8 @@ def test_load_submission(tmp_path: Path) -> None:
     assert submission.kwargs == {"y": 68}
     # Loading submission doesn't evaluate them.
     assert submission._result is None
+
+
+def test_weird_dir(weird_tmp_path: Path) -> None:
+    executor = local.LocalExecutor(weird_tmp_path / "%j")
+    executor.submit(f66, 67, 68).result()
